      function [elv] = eca2elv(eca,alt)
%
%         earth central angle and altitude to elevation angle
%
%    input:
%              eca       earth central angle, deg
%                        limited to +/- 90 deg
%              alt       altitude in km
%
%    output:
%              elv       elevation angle degrees
%
%    -- assumes spherical earth at Re = 6378 km
%
%
      ecau  =  abs(eca);
      ecar  =  ecau * pi/180.0;
%
      seca  =  sin(ecar);
      ceca  =  cos(ecar);
%
      re    =  6378.0;
%
      rsat  =  alt + re;
      num   =  rsat * seca;
      dom   =  rsat * ceca - re;
%
      zenthr =   atan2( num,dom);
%
      elvr   = (pi/2) - zenthr;
      elv    =  180.0 * elvr / pi;
%
