       function [srkm,eca,hrng] =  elvgeoml(elv,altbeg,dalt)
%
%         elevation angle to geometry for a layer
%    
%    input:
%              elv       elevation angle deg
%              altbeg    altitude in km  layer bottom
%              dalt      layer thickness in km
%
%    output:
%              srkm      slant range in km 
%              eca       earth central angle in deg
%              hrng      horizontal range along lower boundary
%
%         used  6378 km  as earth radius 
%
     elvr = (pi/180.0) * elv ;
%
     rearth =  6378.;
%
     alt    =  dalt;
     rbeg   =  rearth + altbeg;
%
     res    =  rbeg*rbeg;
%
     ralt   = rbeg + alt;
     ralts  = ralt.*ralt;
%
     beta   = elvr + pi/2.0;
     cbeta  = cos(beta);
     rcb    = rbeg*cbeta;
     dissq  = rcb.*rcb + ralts - res;
     s      = rcb + sqrt ( dissq );
%
     num    = res + ralts - s.*s;
     dom    = 2.0*rbeg*ralt;
     ctheta = num./dom;
%
     thetar = acos(ctheta);
%
     srkm   =  s;
     eca    =  thetar*180.0/pi;
     hrng   = rbeg * thetar;
%
